@@ -1,5 +1,10 @@
 //! Internal Helper types
 
+// Serialization of large numbers can result in overflows
+// The time calculations are prone to this, so lint here extra
+// https://github.com/jonasbb/serde_with/issues/771
+#![warn(clippy::as_conversions)]
+
 use crate::{
     formats::{Flexible, Format, Strict, Strictness},
     prelude::*,
@@ -23,13 +28,17 @@ impl Sign {
         *self == Sign::Negative
     }
 
-    pub(crate) fn apply<T>(&self, value: T) -> T
-    where
-        T: core::ops::Neg<Output = T>,
-    {
+    pub(crate) fn apply_f64(&self, value: f64) -> f64 {
         match *self {
             Sign::Positive => value,
-            Sign::Negative => value.neg(),
+            Sign::Negative => -value,
+        }
+    }
+
+    pub(crate) fn apply_i64(&self, value: i64) -> Option<i64> {
+        match *self {
+            Sign::Positive => Some(value),
+            Sign::Negative => value.checked_neg(),
         }
     }
 }
@@ -48,6 +57,16 @@ impl DurationSigned {
         }
     }
 
+    pub(crate) fn checked_mul(mut self, rhs: u32) -> Option<Self> {
+        self.duration = self.duration.checked_mul(rhs)?;
+        Some(self)
+    }
+
+    pub(crate) fn checked_div(mut self, rhs: u32) -> Option<Self> {
+        self.duration = self.duration.checked_div(rhs)?;
+        Some(self)
+    }
+
     #[cfg(any(feature = "chrono_0_4", feature = "time_0_3"))]
     pub(crate) fn with_duration(sign: Sign, duration: Duration) -> Self {
         Self { sign, duration }
@@ -102,24 +121,6 @@ impl From<&SystemTime> for DurationSigned {
     }
 }
 
-impl core::ops::Mul<u32> for DurationSigned {
-    type Output = DurationSigned;
-
-    fn mul(mut self, rhs: u32) -> Self::Output {
-        self.duration *= rhs;
-        self
-    }
-}
-
-impl core::ops::Div<u32> for DurationSigned {
-    type Output = DurationSigned;
-
-    fn div(mut self, rhs: u32) -> Self::Output {
-        self.duration /= rhs;
-        self
-    }
-}
-
 impl<STRICTNESS> SerializeAs<DurationSigned> for DurationSeconds<u64, STRICTNESS>
 where
     STRICTNESS: Strictness,
@@ -156,9 +157,17 @@ where
     where
         S: Serializer,
     {
-        let mut secs = source.sign.apply(source.duration.as_secs() as i64);
+        let mut secs = source
+            .sign
+            .apply_i64(i64::try_from(source.duration.as_secs()).map_err(|_| {
+                SerError::custom("The Duration of Timestamp is outside the supported range.")
+            })?)
+            .ok_or_else(|| {
+                S::Error::custom("The Duration of Timestamp is outside the supported range.")
+            })?;
 
         // Properly round the value
+        // TODO check for overflows BUG771
         if source.duration.subsec_millis() >= 500 {
             if source.sign.is_positive() {
                 secs += 1;
@@ -178,7 +187,9 @@ where
     where
         S: Serializer,
     {
-        let mut secs = source.sign.apply(source.duration.as_secs() as f64);
+        // as conversions are necessary for floats
+        #[allow(clippy::as_conversions)]
+        let mut secs = source.sign.apply_f64(source.duration.as_secs() as f64);
 
         // Properly round the value
         if source.duration.subsec_millis() >= 500 {
@@ -201,7 +212,14 @@ where
     where
         S: Serializer,
     {
-        let mut secs = source.sign.apply(source.duration.as_secs() as i64);
+        let mut secs = source
+            .sign
+            .apply_i64(i64::try_from(source.duration.as_secs()).map_err(|_| {
+                SerError::custom("The Duration of Timestamp is outside the supported range.")
+            })?)
+            .ok_or_else(|| {
+                S::Error::custom("The Duration of Timestamp is outside the supported range.")
+            })?;
 
         // Properly round the value
         if source.duration.subsec_millis() >= 500 {
@@ -225,7 +243,7 @@ where
     {
         source
             .sign
-            .apply(utils::duration_as_secs_f64(&source.duration))
+            .apply_f64(source.duration.as_secs_f64())
             .serialize(serializer)
     }
 }
@@ -241,7 +259,7 @@ where
     {
         source
             .sign
-            .apply(utils::duration_as_secs_f64(&source.duration))
+            .apply_f64(source.duration.as_secs_f64())
             .to_string()
             .serialize(serializer)
     }
@@ -261,7 +279,8 @@ macro_rules! duration_impls {
             where
                 S: Serializer,
             {
-                $inner::<FORMAT, STRICTNESS>::serialize_as(&(*source * $factor), serializer)
+                let value = source.checked_mul($factor).ok_or_else(|| S::Error::custom("Failed to serialize value as the value cannot be represented."))?;
+                $inner::<FORMAT, STRICTNESS>::serialize_as(&value, serializer)
             }
         }
 
@@ -276,7 +295,8 @@ macro_rules! duration_impls {
                 D: Deserializer<'de>,
             {
                 let dur = $inner::<FORMAT, STRICTNESS>::deserialize_as(deserializer)?;
-                Ok(dur / $factor)
+                let dur = dur.checked_div($factor).ok_or_else(|| D::Error::custom("Failed to deserialize value as the value cannot be represented."))?;
+                Ok(dur)
             }
         }
 
@@ -296,7 +316,7 @@ duration_impls!(
 );
 
 struct DurationVisitorFlexible;
-impl<'de> Visitor<'de> for DurationVisitorFlexible {
+impl Visitor<'_> for DurationVisitorFlexible {
     type Value = DurationSigned;
 
     fn expecting(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
@@ -307,11 +327,12 @@ impl<'de> Visitor<'de> for DurationVisitorFlexible {
     where
         E: DeError,
     {
-        if value >= 0 {
-            Ok(DurationSigned::new(Sign::Positive, value as u64, 0))
+        let sign = if value >= 0 {
+            Sign::Positive
         } else {
-            Ok(DurationSigned::new(Sign::Negative, (-value) as u64, 0))
-        }
+            Sign::Negative
+        };
+        Ok(DurationSigned::new(sign, value.unsigned_abs(), 0))
     }
 
     fn visit_u64<E>(self, secs: u64) -> Result<Self::Value, E>
@@ -386,11 +407,11 @@ impl<'de> DeserializeAs<'de, DurationSigned> for DurationSeconds<String, Strict>
     {
         struct DurationDeserializationVisitor;
 
-        impl<'de> Visitor<'de> for DurationDeserializationVisitor {
+        impl Visitor<'_> for DurationDeserializationVisitor {
             type Value = DurationSigned;
 
             fn expecting(&self, formatter: &mut fmt::Formatter<'_>) -> fmt::Result {
-                write!(formatter, "a string containing a number")
+                formatter.write_str("a string containing a number")
             }
 
             fn visit_str<E>(self, value: &str) -> Result<Self::Value, E>
@@ -503,7 +524,16 @@ fn parse_float_into_time_parts(mut value: &str) -> Result<(Sign, u64, u32), Pars
             let seconds = parts.next().expect("Float contains exactly one part");
             if let Ok(seconds) = seconds.parse() {
                 let subseconds = parts.next().expect("Float contains exactly one part");
-                let subseclen = subseconds.chars().count() as u32;
+                let subseclen = u32::try_from(subseconds.chars().count()).map_err(|_| {
+                    #[cfg(feature = "alloc")]
+                    return ParseFloatError::Custom(alloc::format!(
+                        "Duration and Timestamps with no more than 9 digits precision, but '{value}' has more"
+                    ));
+                    #[cfg(not(feature = "alloc"))]
+                    return ParseFloatError::Custom(
+                        "Duration and Timestamps with no more than 9 digits precision",
+                    );
+                })?;
                 if subseclen > 9 {
                     #[cfg(feature = "alloc")]
                     return Err(ParseFloatError::Custom(alloc::format!(
